# DOI Output Table Schema

This is the schema for the DOI table output. It is captured on this separate page due to its length.

``` eval_rst
.. csv-table::
   :file: ../schemas/doi_latest.csv
   :width: 100%
   :header-rows: 1
```